@@ -6,5 +6,6 @@ var group__pw__utils =
     [ "pw_split_walk", "group__pw__utils.html#ga86777dfdd21dbb21a2c74470aad019a4", null ],
     [ "pw_split_strv", "group__pw__utils.html#gacdc181bb9d9a0be73f19ad2745630399", null ],
     [ "pw_free_strv", "group__pw__utils.html#ga80e0ca15ccef3f20ef9524a26d8c2b45", null ],
-    [ "pw_strip", "group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9", null ]
+    [ "pw_strip", "group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9", null ],
+    [ "pw_getrandom", "group__pw__utils.html#ga47fc8395e1484903507ade1668582bf8", null ]
 ];
\ No newline at end of file
