@@ -12,6 +12,9 @@ var group__spa__string =
     [ "spa_atob", "group__spa__string.html#ga16da26e2202a32c64061f92dec72dfc5", null ],
     [ "spa_vscnprintf", "group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6", null ],
     [ "spa_scnprintf", "group__spa__string.html#gae194d9bc956defbfe180dc658e3df052", null ],
+    [ "spa_strtof", "group__spa__string.html#ga928368a5adc237123fe3097ddf09061d", null ],
     [ "spa_atof", "group__spa__string.html#gace4942742ce246641a3cb3b4b2540e05", null ],
-    [ "spa_atod", "group__spa__string.html#ga0b03d1967a0ee32027c1efb16fec49de", null ]
+    [ "spa_strtod", "group__spa__string.html#ga0faf9c1cc2f41796a16399193bbdb263", null ],
+    [ "spa_atod", "group__spa__string.html#ga0b03d1967a0ee32027c1efb16fec49de", null ],
+    [ "spa_dtoa", "group__spa__string.html#gae9be2db04a7f11c3ff07b78f635c9fe3", null ]
 ];
\ No newline at end of file
