@@ -58,26 +58,26 @@ var NAVTREEINDEX =
 "annotated.html",
 "globals_defs_p.html",
 "globals_l.html",
-"group__pw__control.html",
-"group__pw__impl__link.html#gacc36539d4d6dfb2064d0ffa36b13d0ae",
-"group__pw__link.html#gga7859f6eb040fead1673d0214b83b445ba369af04b8025470a27c313640bbb4bc0",
-"group__pw__port.html#gafaf94d5ec6fb0f925c2f70a34b8ed190",
-"group__pw__session__manager.html#gaaa4097e754be1ef65c9cd385043ef35c",
-"group__spa__ansi.html#gab2f81c97caf8615cf3d9399aec7ee601",
-"group__spa__device.html#gad20dd1ca2095057a6af2ad7601947e49",
-"group__spa__log.html#ga73863d235426379d73a1defd3191877c",
-"group__spa__node.html#gaf0edf0bcb3ae5739c7a528dc99fab618",
-"group__spa__param.html#gaeff8b2b0ae279f80bce7b0765e39ccd9",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81acabf59a8bfe97068a9c6d98173b6aef7",
-"group__spa__param.html#ggacf6ba1ad0a715f691fcc3105cdffc30daa386d5660ebd59714792b129973b4be3",
-"group__spa__pod.html#ga7dcee1f3ff7993a0b3f80c224977d1f4",
-"group__spa__types.html#gad9c69f01ba4f4907c8550164be6d3d49",
-"page_proxy.html#sec_page_proxy_create",
-"structpw__endpoint__link__events.html",
-"structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01",
-"structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7",
-"structspa__latency__info.html#a9b3d5d2e366d8081d91adcf736b15c48",
-"structspa__poll__event.html"
+"group__pw__context.html#gae01b3e37bd9c02da61ac4bad64dc7217",
+"group__pw__impl__link.html#ga8a9522e49aa17d076831c7e18026bc5a",
+"group__pw__link.html#gga7859f6eb040fead1673d0214b83b445ba1cdbf68b2f1a25b0c6202141e9069f70",
+"group__pw__port.html#gada3484ae34475c97571c091b7494d7b3",
+"group__pw__session__manager.html#gaa8366fa5903ce48d728d5a4bf1eb6ff2",
+"group__spa__ansi.html#gaad15091a1f40cc819dff1fc80374cc34",
+"group__spa__device.html#gacbe7c7131058a38cd357c7028387a1ff",
+"group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8",
+"group__spa__node.html#gaed43186ba554d0253f721dda55ffe84d",
+"group__spa__param.html#gaee9165d1be224b58538dffab9ba90ba9",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81abf1fd7357ac7a7ad41615e4aee046731",
+"group__spa__param.html#ggacf6ba1ad0a715f691fcc3105cdffc30da3d42db97944bf4ee99d7d9c011a96302",
+"group__spa__pod.html#ga7c658bc2f25b9a3271292df883a16cd7",
+"group__spa__types.html#gaaaa70c8c33c359627dd29efe58e62503",
+"page_portal.html#autotoc_md39",
+"structpw__endpoint__info.html#a652272ff97cabdbc2cb630e631319894",
+"structpw__module__info.html#a027112b51093afc0ec6370a549bcb29f",
+"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560",
+"structspa__json.html#a8a0962e6aafa40f4b0124bcbb94e04df",
+"structspa__pod__string.html#aa7b8596a64741c1f0b728bc066643c79"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
