@@ -1,5 +1,8 @@
 var NAVTREEINDEX10 =
 {
+"group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8":[6,8,9,3,39],
+"group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e":[6,8,9,3,33],
+"group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6":[6,8,9,3,15],
 "group__spa__log.html#ga73863d235426379d73a1defd3191877c":[6,8,9,3,40],
 "group__spa__log.html#ga750a6ac2af9bf84c4b59af14d6cbe22f":[6,8,9,3,12],
 "group__spa__log.html#ga7d4019336333f5cdf8b82514a6865b79":[6,8,9,3,37],
@@ -246,8 +249,5 @@ var NAVTREEINDEX10 =
 "group__spa__node.html#gae30aeb4988d0b38916a8e40fe3620b65":[6,8,6,145],
 "group__spa__node.html#gae5da16ead1c0ebe3f41d5b3ee27d4f60":[6,8,6,151],
 "group__spa__node.html#gae69edc800effe1c3f70e163611784a04":[6,8,6,36],
-"group__spa__node.html#gae881bab892a51d30cf3959fb03016b13":[6,8,6,89],
-"group__spa__node.html#gaed43186ba554d0253f721dda55ffe84d":[6,8,6,102],
-"group__spa__node.html#gaee7d45b6819789bde3de86d9be592a3a":[6,8,6,119],
-"group__spa__node.html#gaeee49d051bb080669113c6deeffa5d90":[6,8,6,80]
+"group__spa__node.html#gae881bab892a51d30cf3959fb03016b13":[6,8,6,89]
 };
