@@ -1,5 +1,8 @@
 var NAVTREEINDEX15 =
 {
+"group__spa__pod.html#ga7c658bc2f25b9a3271292df883a16cd7":[6,8,0,312],
+"group__spa__pod.html#ga7c95b0ed12cb9e712b64568144c8edd6":[6,8,0,77],
+"group__spa__pod.html#ga7d41061d62cfb1d25b3d35e35c3566ed":[6,8,0,227],
 "group__spa__pod.html#ga7dcee1f3ff7993a0b3f80c224977d1f4":[6,8,0,119],
 "group__spa__pod.html#ga7f59bef75b6bc82839180380bf3c3dd5":[6,8,0,72],
 "group__spa__pod.html#ga7fda864b19555161ffa6b0bce9045fa8":[6,8,0,316],
@@ -218,15 +221,17 @@ var NAVTREEINDEX15 =
 "group__spa__system.html#gafc0c4bc774b7d7f571cfc311223cd01c":[6,8,9,7,34],
 "group__spa__system.html#gaff95a55ae068dc73d2434f5bf40bdb9a":[6,8,9,7,29],
 "group__spa__thread.html":[6,8,9,8],
-"group__spa__thread.html#ga087f55566e08c2bb1536574b7556a66f":[6,8,9,8,11],
-"group__spa__thread.html#ga13cf7d6799ad80fe7e3f69874032d529":[6,8,9,8,10],
+"group__spa__thread.html#ga087f55566e08c2bb1536574b7556a66f":[6,8,9,8,13],
+"group__spa__thread.html#ga13cf7d6799ad80fe7e3f69874032d529":[6,8,9,8,12],
 "group__spa__thread.html#ga36d6661f31950920b85cd0c48fc68a33":[6,8,9,8,4],
 "group__spa__thread.html#ga4f716da417d838544df4e82f4670b79c":[6,8,9,8,6],
+"group__spa__thread.html#ga5d2d0635caeef22aaa5a63681255219d":[6,8,9,8,9],
 "group__spa__thread.html#ga6680e7f42845ca460cdaa93abd568e02":[6,8,9,8,5],
 "group__spa__thread.html#ga7454dd6c4ac2967b5c53936dc6ec00b5":[6,8,9,8,7],
-"group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41":[6,8,9,8,8],
-"group__spa__thread.html#ga8dcf8fcd02dbf3c2c49afe37e40b6a43":[6,8,9,8,9],
-"group__spa__thread.html#gae1224b4702957d8a48f7c17cf350f5a2":[6,8,9,8,12],
+"group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41":[6,8,9,8,10],
+"group__spa__thread.html#ga8dcf8fcd02dbf3c2c49afe37e40b6a43":[6,8,9,8,11],
+"group__spa__thread.html#gaa3418c60a3ab55c44596d0c37ff0fe1b":[6,8,9,8,8],
+"group__spa__thread.html#gae1224b4702957d8a48f7c17cf350f5a2":[6,8,9,8,14],
 "group__spa__types.html":[6,8,8,12],
 "group__spa__types.html#ga0c6d1b17fc516da2e38cea3e1c7c859c":[6,8,8,12,24],
 "group__spa__types.html#ga12e7f34d2ebf7bb4ad1b14997148383f":[6,8,8,12,8],
@@ -244,10 +249,5 @@ var NAVTREEINDEX15 =
 "group__spa__types.html#ga94dcb50c9935bbe4cbfa8b229dca36ce":[6,8,8,12,13],
 "group__spa__types.html#ga9e1a81c8210e152df8ef719874f50966":[6,8,8,12,16],
 "group__spa__types.html#ga9f782261111d9f99e61840289e47e8e3":[6,8,8,12,25],
-"group__spa__types.html#gaa055f9a506370480ced82ad6cccf13db":[6,8,8,12,12],
-"group__spa__types.html#gaaaa70c8c33c359627dd29efe58e62503":[6,8,8,12,6],
-"group__spa__types.html#gaaca7a372068124b38f09b0bd2fef0f98":[6,8,8,12,4],
-"group__spa__types.html#gab8f02181d37e1c034e04797628a8ee1b":[6,8,8,12,5],
-"group__spa__types.html#gacca81d9bddca49922a0945a9b58b5e39":[6,8,8,12,21],
-"group__spa__types.html#gad3685dd5b8d7658dd24b77fad4a721bc":[6,8,8,12,20]
+"group__spa__types.html#gaa055f9a506370480ced82ad6cccf13db":[6,8,8,12,12]
 };
