@@ -1,11 +1,17 @@
 var NAVTREEINDEX19 =
 {
+"structpw__module__info.html#a027112b51093afc0ec6370a549bcb29f":[6,4,9,1,0],
+"structpw__module__info.html#a1578038e841f4d0e8ac4348f263124c8":[6,4,9,1,1],
+"structpw__module__info.html#a8991e7a078e6d92aa05e1922efc5bc53":[6,4,9,1,2],
+"structpw__module__info.html#aae79b994769838377e2b549736f12de3":[6,4,9,1,3],
+"structpw__module__methods.html":[6,4,9,3],
+"structpw__module__methods.html#ac20cd689bc54dcab9452e65c58fc5da3":[6,4,9,3,0],
 "structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01":[6,4,9,3,1],
 "structpw__node.html":[6,4,10,4],
 "structpw__node__events.html":[6,4,10,2],
-"structpw__node__events.html#a07c012e13056aed56de654a44590df89":[6,4,10,2,2],
+"structpw__node__events.html#a31efa366284e12aa933c87ac63290adf":[6,4,10,2,1],
 "structpw__node__events.html#a37faf21db57a7e95999db521fb1cbcab":[6,4,10,2,0],
-"structpw__node__events.html#a9a6cdaf300007bc554b0c0b6bdbf5ccd":[6,4,10,2,1],
+"structpw__node__events.html#aa945ae608ff9a37d9fb0a2a24208caff":[6,4,10,2,2],
 "structpw__node__info.html":[6,4,10,1],
 "structpw__node__info.html#a125f4d8851630b989c86fc0ebc83fba0":[6,4,10,1,6],
 "structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e":[6,4,10,1,1],
@@ -29,9 +35,9 @@ var NAVTREEINDEX19 =
 "structpw__permission.html#ac890cf00fa67d8667c9be52276e8a6f3":[6,4,11,1,1],
 "structpw__port.html":[6,4,12,4],
 "structpw__port__events.html":[6,4,12,2],
-"structpw__port__events.html#a287b7ffb7f8f5b99b82bdd61d137cb1f":[6,4,12,2,1],
+"structpw__port__events.html#a8f4e9ac2f2e40c313fa06e2f2d6fdced":[6,4,12,2,1],
 "structpw__port__events.html#ab9b6466b9ef1ed29b53c585e6d7d5885":[6,4,12,2,0],
-"structpw__port__events.html#ac3ad235f94b8be2c65b694c8ebf26457":[6,4,12,2,2],
+"structpw__port__events.html#afee93a171006705e6e7ee53c4ba08a18":[6,4,12,2,2],
 "structpw__port__info.html":[6,4,12,1],
 "structpw__port__info.html#a3c95bbed7080e2f033b133409315f31a":[6,4,12,1,4],
 "structpw__port__info.html#a5131d23e86aef3c0d1727a6aa6359e9c":[6,4,12,1,3],
@@ -46,7 +52,7 @@ var NAVTREEINDEX19 =
 "structpw__profiler.html":[6,7,2,3],
 "structpw__profiler__events.html":[6,7,2,1],
 "structpw__profiler__events.html#a00e0a36b711bd01ce994d368e0e39629":[6,7,2,1,0],
-"structpw__profiler__events.html#a1ca3197b5f29567d7dfa437d86695e9a":[6,7,2,1,1],
+"structpw__profiler__events.html#ab4f32595bfcc74f3c77ccc9cb0bb2acb":[6,7,2,1,1],
 "structpw__profiler__methods.html":[6,7,2,2],
 "structpw__profiler__methods.html#a036f959bbeba1ad5da22f20c0e66a1f8":[6,7,2,2,1],
 "structpw__profiler__methods.html#a6d6488538db93934b63ad3ee7fc3cc9a":[6,7,2,2,0],
@@ -119,9 +125,9 @@ var NAVTREEINDEX19 =
 "structpw__proxy__events.html#af8e0510a58d92ddd0831293e1c42b867":[6,4,13,1,5],
 "structpw__registry.html":[6,4,4,5],
 "structpw__registry__events.html":[6,4,14,1],
-"structpw__registry__events.html#a3fa28cf2cd3ed8739debec5bb17ace61":[6,4,14,1,2],
+"structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97":[6,4,14,1,2],
+"structpw__registry__events.html#a37bd7089a7a07d7154e111e67b25f96c":[6,4,14,1,1],
 "structpw__registry__events.html#a94464d7de86207e80a3dff93974b1a01":[6,4,14,1,0],
-"structpw__registry__events.html#a9a62b37a711f65f1014cb27b92ae2689":[6,4,14,1,1],
 "structpw__registry__methods.html":[6,4,14,2],
 "structpw__registry__methods.html#a743174c4df93282f1361f137383cb41a":[6,4,14,2,2],
 "structpw__registry__methods.html#a82488a74c02c5b764b0764b0d3e42fac":[6,4,14,2,0],
@@ -135,8 +141,8 @@ var NAVTREEINDEX19 =
 "structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2":[6,5,14,1,3],
 "structpw__session.html":[6,7,4,24],
 "structpw__session__events.html":[6,7,4,10],
-"structpw__session__events.html#a0b39596a01a8c3d325dcf0548c64dc29":[6,7,4,10,2],
-"structpw__session__events.html#a7199c3db69d83133dfdf110524ea90b4":[6,7,4,10,1],
+"structpw__session__events.html#a36371c5decff93c9c0c0688c19b2780c":[6,7,4,10,1],
+"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7":[6,7,4,10,2],
 "structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[6,7,4,10,0],
 "structpw__session__info.html":[6,7,4,18],
 "structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[6,7,4,18,3],
@@ -213,8 +219,8 @@ var NAVTREEINDEX19 =
 "structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[7,0,140,0],
 "structspa__audio__info.html":[6,8,7,20],
 "structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[6,8,7,20,5],
-"structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[6,8,7,20,6],
 "structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[6,8,7,20,3],
+"structspa__audio__info.html#a1c0fd971fb059d844722a21feeb3de59":[6,8,7,20,6],
 "structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[6,8,7,20,1],
 "structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[6,8,7,20,2],
 "structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[6,8,7,20,0],
@@ -243,11 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[6,8,7,22,0],
 "structspa__buffer.html":[6,8,1,7],
 "structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[6,8,1,7,0],
-"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[6,8,1,7,2],
-"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560":[6,8,1,7,3],
-"structspa__buffer.html#adbf5510ef0707e22b19980c84b61a073":[6,8,1,7,1],
-"structspa__buffer__alloc__info.html":[6,8,1,4],
-"structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6":[6,8,1,4,11],
-"structspa__buffer__alloc__info.html#a30233569ad362f458d9e1344d0b5a58c":[6,8,1,4,10],
-"structspa__buffer__alloc__info.html#a49810ff55f219eea5c1e4a3e2f24cd4c":[6,8,1,4,2]
+"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[6,8,1,7,2]
 };
