@@ -1,5 +1,11 @@
 var NAVTREEINDEX21 =
 {
+"structspa__json.html#a8a0962e6aafa40f4b0124bcbb94e04df":[6,8,8,6,1,3],
+"structspa__json.html#a8c09dbf1f541a944ceef31cb0b4110af":[6,8,8,6,1,1],
+"structspa__json.html#ae765edf5a3ac4c7fe5be87c93f62b0c2":[6,8,8,6,1,2],
+"structspa__latency__info.html":[6,8,7,25],
+"structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101":[6,8,7,25,3],
+"structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec":[6,8,7,25,4],
 "structspa__latency__info.html#a9b3d5d2e366d8081d91adcf736b15c48":[6,8,7,25,0],
 "structspa__latency__info.html#aab5617769d3799f99a80747917268db8":[6,8,7,25,2],
 "structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725":[6,8,7,25,1],
@@ -243,11 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__pod__sequence__body.html":[6,8,0,43],
 "structspa__pod__sequence__body.html#adcbb3a7881352555c1a9340662f25c77":[6,8,0,43,1],
 "structspa__pod__sequence__body.html#ae83a44c4123cc5dc4450a985d4c4445d":[6,8,0,43,0],
-"structspa__pod__string.html":[6,8,0,26],
-"structspa__pod__string.html#aa7b8596a64741c1f0b728bc066643c79":[6,8,0,26,0],
-"structspa__pod__struct.html":[6,8,0,35],
-"structspa__pod__struct.html#a60dbfcf74d9a0dca707123f887817030":[6,8,0,35,0],
-"structspa__point.html":[6,8,8,1,2],
-"structspa__point.html#a4e7f622b7e262885081e0459bafc22eb":[6,8,8,1,2,1],
-"structspa__point.html#ad0e2590c913f99dd1bd9f18aecffc951":[6,8,8,1,2,0]
+"structspa__pod__string.html":[6,8,0,26]
 };
