@@ -1,5 +1,7 @@
 var NAVTREEINDEX6 =
 {
+"group__pw__port.html#gada3484ae34475c97571c091b7494d7b3":[6,4,12,18],
+"group__pw__port.html#gaf355e07f1fb54c06af8e1040c47bd1c3":[6,4,12,12],
 "group__pw__port.html#gafaf94d5ec6fb0f925c2f70a34b8ed190":[6,4,12,28],
 "group__pw__profiler.html":[6,7,2],
 "group__pw__profiler.html#ga07a9df46d368a90b9917e01c186a820f":[6,7,2,10],
@@ -247,7 +249,5 @@ var NAVTREEINDEX6 =
 "group__pw__session__manager.html#gaa50cf4a5a59e55e6a003e21cc6376996":[6,7,4,44],
 "group__pw__session__manager.html#gaa5330ba264cb1a5af498d1a4b33d85ae":[6,7,4,155],
 "group__pw__session__manager.html#gaa6b4a8b98c7447bbd98d4735ba71feae":[6,7,4,128],
-"group__pw__session__manager.html#gaa7bf956682a13c8dabda82c6c388b7e9":[6,7,4,63],
-"group__pw__session__manager.html#gaa8366fa5903ce48d728d5a4bf1eb6ff2":[6,7,4,180],
-"group__pw__session__manager.html#gaa901c089ae02f35b58d4368f99d94b26":[6,7,4,58]
+"group__pw__session__manager.html#gaa7bf956682a13c8dabda82c6c388b7e9":[6,7,4,63]
 };
