@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__spa__device.html#gacbe7c7131058a38cd357c7028387a1ff":[6,8,4,23],
+"group__spa__device.html#gacbf503314e5bd1a38a9baa23b32dec1c":[6,8,4,29],
 "group__spa__device.html#gad20dd1ca2095057a6af2ad7601947e49":[6,8,4,42],
 "group__spa__device.html#gad97ce15937ee02d483156a0937260f76":[6,8,4,56],
 "group__spa__device.html#gadef390bb7a8fbcfca7bf01639ed6b9e6":[6,8,4,40],
@@ -120,14 +122,15 @@ var NAVTREEINDEX9 =
 "group__spa__json.html#ga16c676cb24334b96a9e1eaf0d73ec39f":[6,8,8,6,17],
 "group__spa__json.html#ga255f1962c8cb52c861c197533693732c":[6,8,8,6,16],
 "group__spa__json.html#ga2b070aa36336cbe95ffe1871672ecd70":[6,8,8,6,23],
-"group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96":[6,8,8,6,29],
+"group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96":[6,8,8,6,30],
 "group__spa__json.html#ga4dbbb0d8d43216c23d20b08be1650437":[6,8,8,6,8],
 "group__spa__json.html#ga54e9a5e2c169224c8ae8953135290505":[6,8,8,6,6],
+"group__spa__json.html#ga588b735c81b1826b44076463ff7bff07":[6,8,8,6,29],
 "group__spa__json.html#ga5e367b9297cbf21d391f4d1b2ffe4734":[6,8,8,6,24],
 "group__spa__json.html#ga604d3512668501ff1a1d5897c0208416":[6,8,8,6,22],
 "group__spa__json.html#ga62fe1f66450b557cf2c5b5e65a5fcd70":[6,8,8,6,26],
 "group__spa__json.html#ga6502b3572751902a364273b0cdaa13c4":[6,8,8,6,12],
-"group__spa__json.html#ga6864ecec42015a48aa8991d6a2c8d6fa":[6,8,8,6,31],
+"group__spa__json.html#ga6864ecec42015a48aa8991d6a2c8d6fa":[6,8,8,6,32],
 "group__spa__json.html#ga6c02b51e71c406e5b7f014858bdf579b":[6,8,8,6,25],
 "group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64":[6,8,8,6,2],
 "group__spa__json.html#ga7c080249c08879b0576e5225a67fde7e":[6,8,8,6,19],
@@ -135,7 +138,7 @@ var NAVTREEINDEX9 =
 "group__spa__json.html#ga910d92b40deefb1451ddcdee9b96c243":[6,8,8,6,27],
 "group__spa__json.html#ga9110761cf050dd015410b949edd24350":[6,8,8,6,15],
 "group__spa__json.html#ga9e5319ac5846fb6219a973e0cfa46786":[6,8,8,6,3],
-"group__spa__json.html#gab03680b46f934bdc18755d2156077cf1":[6,8,8,6,32],
+"group__spa__json.html#gab03680b46f934bdc18755d2156077cf1":[6,8,8,6,33],
 "group__spa__json.html#gabc34f55fde305ab5ff6a28d34a642170":[6,8,8,6,20],
 "group__spa__json.html#gac6aa5f68834748dc6790cf5dd2ac9401":[6,8,8,6,7],
 "group__spa__json.html#gacc0420e669d2d9ab67bf711a63373026":[6,8,8,6,9],
@@ -144,7 +147,7 @@ var NAVTREEINDEX9 =
 "group__spa__json.html#gad27e11f0d644f60840cb42bdcc370412":[6,8,8,6,14],
 "group__spa__json.html#gad655166a86f6b9b79fb480603bf63ec3":[6,8,8,6,18],
 "group__spa__json.html#gae465abe3ff0170d6b630ead5901fba56":[6,8,8,6,11],
-"group__spa__json.html#gae51e8d4cc1999ffcc20802cc9e3f8a97":[6,8,8,6,30],
+"group__spa__json.html#gae51e8d4cc1999ffcc20802cc9e3f8a97":[6,8,8,6,31],
 "group__spa__json__pod.html":[6,3],
 "group__spa__json__pod.html#ga7904434cb7205e5aa65caa9a7d225e77":[6,3,2],
 "group__spa__json__pod.html#gaffbc97d3a2e34cca3c9735634c2a3013":[6,3,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX9 =
 "group__spa__log.html#ga3ad08caaedbf23933f4c994cc732ca28":[6,8,9,3,11],
 "group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6":[6,8,9,3,32],
 "group__spa__log.html#ga4d1859244f14f1c31f0f5e446bed3cfc":[6,8,9,3,28],
-"group__spa__log.html#ga54294a1ab30713deee27d8165fb7bd67":[6,8,9,3,6],
-"group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8":[6,8,9,3,39],
-"group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e":[6,8,9,3,33],
-"group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6":[6,8,9,3,15]
+"group__spa__log.html#ga54294a1ab30713deee27d8165fb7bd67":[6,8,9,3,6]
 };
